@@ -1,7 +1,6 @@
 import os
 
 import pytest
-from bravado.client import SwaggerClient
 
 from .utils import FasJsonMock
 
@@ -12,13 +11,6 @@ def fixture_dir():
     return os.path.join(test_dir, "fixtures")
 
 
-@pytest.fixture
-def bravado_client(mocker):
-    client = mocker.Mock(name="mock SwaggerClient")
-    mocker.patch.object(SwaggerClient, "from_url", return_value=client)
-    yield client
-
-
 @pytest.fixture
 def server(fixture_dir):
     with open(f"{fixture_dir}/spec.json") as f:
